package com.qihoo360.mobilesafe.reward.container.app

import android.content.Context
import android.util.AttributeSet
import android.view.View
import android.widget.Toast
import com.qihoo360.apullsdk.apull.ApullConst
import com.qihoo360.apullsdk.apull.control.sync.DownloadSatusManager
import com.qihoo360.apullsdk.apull.protocol.ApullReportManager
import com.qihoo360.apullsdk.apull.protocol.model.ApullTemplateBase
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullApp
import com.qihoo360.apullsdk.apull.view.impl.ContainerApullAppBase
import com.qihoo360.apullsdk.apull.view.utils.ApullTextPatchUtil
import com.qihoo360.apullsdk.support.cache.ApullTemplateCacheUtil
import com.qihoo360.apullsdk.utils.NetUtil
import com.qihoo360.apullsdk.videoad.view.AdOperationListener
import com.qihoo360.mobilesafe.extension.onClick
import com.qihoo360.mobilesafe.extension.setVisible
import com.qihoo360.mobilesafe.reward.R
import com.qihoo360.mobilesafe.reward.container.displayImage
import com.qihoo360.mobilesafe.reward.data.ApullItemWrapper
import com.qihoo360.mobilesafe.reward.data.RewardRecordManager
import com.qihoo360.mobilesafe.reward.data.RewardUtils
import com.qihoo360.mobilesafe.reward.presenter.view.RewardView
import com.qihoo360.mobilesafe.reward.ui.page.dialog.RewardDownloadDialog
import com.qihoo360.mobilesafe.ui.common.dialog.CommonDialog
import kotlinx.android.synthetic.main.apullsdk_container_apull_app_37.view.*

/**
 * 专场红包
 */
class ContainerApullApp37 : ContainerApullAppBase {

    constructor(context: Context, template: ApullTemplateBase?, listener: AdOperationListener) :super(context,template,listener)

    constructor(context: Context, template: ApullTemplateBase?) :super(context,template)

    constructor(context: Context, attrs: AttributeSet) :super(context,attrs)

    constructor(context: Context, attrs: AttributeSet, defStyle : Int) :super(context,attrs,defStyle)

    override fun initView(template: ApullTemplateBase?) {
        View.inflate(context, R.layout.apullsdk_container_apull_app_37, this)
        DownloadSatusManager.register(this)
    }

    override fun updateView(template: ApullTemplateBase?) {
        if(template is TemplateApullApp && template != templateApullApp) {
            templateApullApp = template
            setVisible(true)
            templateApullApp?.app_list?.let {
                apullAppItem = templateApullApp.app_list[0]
                updateText()
                updateImage()
                addClickListener()
            }

        }
    }

    private fun addClickListener(){
        mRoot37?.onClick {
            handleAppClick(TYPE_BUTTON)
        }
    }


    override fun startDownloadApp(type: Int) {
        if(context is RewardView){
            (context as? RewardView)?.showRewardDownloadDialog(
                    ApullItemWrapper(templateApullApp),mDownloadListener)
        }
        RewardRecordManager.setLastRewardUniqueId(context,apullAppItem?.unique_id)

        super.startDownloadApp(type)
    }

    fun startDownloadAppNoDialog(type: Int) {
        super.startDownloadApp(type)
    }

    private fun updateImage() {
        mLargeImage37?.apply {
            val url = apullAppItem?.image_url
            displayImage(url)
        }
        if(RewardUtils.RewardInfo.isActivateOrRegisterType(templateApullApp)){
            mRegisterIcon?.setVisible(true)
        }
    }

    private fun updateText() {
        mAppName37?.text = ApullTextPatchUtil.getFormatText(context,
                apullAppItem?.app_name, apullAppItem?.app_name_patch)

        if(apullAppItem?.status == ApullConst.STATUS_TYPE_INSTALL_FINISHED){
            mRewardBtn37?.text = context.getText(R.string.open)
        }else{
            mRewardBtn37?.text = context.getText(R.string.get_hongbao)
        }

    }

    override fun startDownloadAppWithTips(type: Int) {
        if (NetUtil.isConnected(context)) {
            if (!NetUtil.isWifiConnected(context)) {
                val title = context.getString(R.string.tips_title)
                val body = context.getString(R.string.tips_body_start_download)
                val ok = context.getString(R.string.ok)
                val cancel = context.getString(R.string.cancel)
                val dialog = CommonDialog(context,title,body)
                dialog.setBtnOk(ok) {
                    startDownloadApp(TYPE_BUTTON)
                    dialog.dismiss()
                }
                dialog.setBtnCancel(cancel){
                    dialog.dismiss()
                }
                dialog.show()

            } else {
                startDownloadApp(type)
            }
        } else {
            Toast.makeText(context, R.string.hongbao_net_no_connect_tips, Toast.LENGTH_SHORT).show()
        }
    }

    override fun openApp() {
        RewardRecordManager.setLastRewardUniqueId(context,apullAppItem?.unique_id)
        super.openApp()
    }

    override fun onImageEnableChange(enable: Boolean) {
        updateImage()
    }


    override fun updateStatusInUi() {
        post{
            if (apullAppItem?.status == ApullConst.STATUS_TYPE_INSTALL_FINISHED) {
                if (templateApullApp?.installed_reported == false) {
                    templateApullApp.installed_reported = true
                    ApullTemplateCacheUtil.refresh(templateApullApp)
                    ApullReportManager.reportApullSspAppInstalled(context, templateApullApp)
                }
            }
            updateText()
        }
    }

   private val mDownloadListener = object : RewardDownloadDialog.DownloadListener {

        override fun onClick() {
           apullAppItem?.apply {
               if (apullAppItem.status == ApullConst.STATUS_TYPE_DOWNLOAD_PAUSED) {
                   startDownloadAppNoDialog(TYPE_BUTTON)
                   return
               }
               handleAppClick(TYPE_BUTTON)
           }
        }

        override fun onDismiss() {
            apullAppItem?.apply {
                if(apullAppItem.status == ApullConst.STATUS_TYPE_DOWNLOADING ||
                        apullAppItem.status == ApullConst.STATUS_TYPE_UPDATE_PROGRESS){
                    handleAppClick(TYPE_BUTTON)
                }
            }
        }

        override fun onContinue() {
            apullAppItem?.apply {
                if (apullAppItem.status == ApullConst.STATUS_TYPE_DOWNLOAD_PAUSED) {
                    startDownloadAppNoDialog(TYPE_BUTTON)
                }
            }
        }

    }

}