package com.qihoo360.mobilesafe.reward.ui.page.dialog

import android.app.Activity
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.view.View
import com.qihoo360.apullsdk.apull.ApullConst
import com.qihoo360.apullsdk.apull.control.sync.DownloadSatusManager
import com.qihoo360.apullsdk.apull.control.sync.DownloadSyncInterface
import com.qihoo360.apullsdk.apull.protocol.model.impl.app.ApullAppItem
import com.qihoo360.apullsdk.apull.view.utils.ApullTextPatchUtil
import com.qihoo360.apullsdk.utils.BitmapUtil
import com.qihoo360.apullsdk.utils.DensityUtil
import com.qihoo360.mobilesafe.extension.setVisible
import com.qihoo360.mobilesafe.extension.tryCatch
import com.qihoo360.mobilesafe.reward.AnimationShake

import com.qihoo360.mobilesafe.reward.R
import com.qihoo360.mobilesafe.reward.container.displayImage
import com.qihoo360.mobilesafe.reward.data.ApullItemWrapper
import com.qihoo360.mobilesafe.reward.data.ApullItemWrapper.Companion.APP
import com.qihoo360.mobilesafe.reward.data.RewardUtils
import com.qihoo360.mobilesafe.reward.ui.page.RaffleBaseActivity
import com.qihoo360.mobilesafe.support.log.Logger
import com.qihoo360.mobilesafe.ui.common.dialog.CommonBaseDialog
import com.qihoo360.mobilesafe.ui.common.dialog.CommonDialog
import kotlinx.android.synthetic.main.dialog_reward_download.*
import org.w3c.dom.Text

open class RewardDownloadDialog  constructor(private var mContext: Activity, var mApullItemWrapper: ApullItemWrapper?, private var mDownloadListener: DownloadListener?) : CommonBaseDialog(mContext,R.style.apull_dialog),
        DownloadSyncInterface, View.OnClickListener{

    companion object {
        const val TAG = "RewardDownloadDialog"
        var DEBUG = Logger.bDebug()
        const val RADIUS_DP:Float = 16.0f
        const val INIT:Int = 1 //初始化
        const val TIMEOUT:Int = 2 //try/commit超时
        const val DONT_HAS_CHANCE = 3 //没有机会
        const val SHARE_MORE_CHANCE = 4 //分享后还有一次机会
        const val HAS_REWARD = 5 //可以commit
    }

    private val mClickInterval :Long = 800

    private var mLastClick :Long = 0

    private val isClickTooFast :Boolean
        get() {
            val now = System.currentTimeMillis()
            if(Math.abs(now - mLastClick) < mClickInterval){
                return true
            }
            mLastClick = now
            return false
        }

    var mRewardInfo :RewardUtils.RewardInfo? = null

    var openAppShouldCloseDialog = false

    var mRewardCome = false

    protected var mHandler = Handler()

    var mRewardType = 0

    private var mShareCanTryAgain = false

    protected var mCommitTimeOut = false

    init {
        if(mDownloadListener != null){
            mRewardType = RewardUtils.REWARD_TYPE_APP
        }
    }
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(setLayoutId())
        setCanceledOnTouchOutside(false)
        initView()
    }

    protected open fun  setLayoutId() :Int {
        return R.layout.dialog_reward_download
    }

    private fun initView() {
        mDownloadClose.setOnClickListener(this)
        mDownloadIcon.setOnClickListener(this)
        mDownloadBtn.setOnClickListener(this)

        updateStatus(mApullItemWrapper)

        DownloadSatusManager.register(this)

        mDownloadIcon?.apply {
            val url = mApullItemWrapper?.getIconUrl()
            if(mApullItemWrapper?.getProtocolType() == ApullItemWrapper.GDT_SDK_REWARD_VIDEO ||
                    mApullItemWrapper?.getProtocolType() == ApullItemWrapper.TOUTIAO_SDK_REWARD_VIDEO){
                setImageResource(R.drawable.hongbao_rewardvideo_sdk_default)
            }else {
                displayImage(url)
            }
        }
        updateText(INIT)
        initProgressBtn()
    }

    open fun initProgressBtn(){
        mDownloadBtn?.setTextDimenSp(16)
        mDownloadBtn?.setTextColor(Color.parseColor("#ffe5a8"))
        var drawable = BitmapUtil.createSolidDrawable(context, DensityUtil.dip2px(context, RADIUS_DP),
                Color.parseColor("#ffe5a8"), 0, false, 1f)
        mDownloadBtn?.setBackgroundDrawable(drawable)
        drawable = BitmapUtil.createSolidDrawable(context, DensityUtil.dip2px(context, RADIUS_DP),
                Color.parseColor("#ffe5a8"), context.resources.getColor(R.color.progress_yellow), true, 1f)
        mDownloadBtn?.progressDrawable = drawable
    }

    open fun updateStatus(apullItemWrapper: ApullItemWrapper?) {
        mHandler.post{
            if(apullItemWrapper == null){
                return@post
            }
            mApullItemWrapper?.apply {
                if (equalsUniqueId(apullItemWrapper)) {
                    mApullItemWrapper = apullItemWrapper

                    if (mRewardCome) {
                        return@post
                    }
                    val status = getDownloadStatus()
                    val progress = getDownloadProgress()
                    val buttonText = if (getProtocolType() == APP) {
                        (getDefaultItem(false) as? ApullAppItem)?.let {
                            if (!it.button_text.isNullOrEmpty()) {
                                val text = ApullTextPatchUtil.getFormatText(context, it.button_text, it.button_text_patch).toString()
                                if (!text.isEmpty()) {
                                    text
                                } else {
                                    null
                                }
                            } else {
                                null
                            }
                        }
                    } else {
                        null
                    }
                    when(status){
                        ApullConst.STATUS_TYPE_DOWNLOAD ->{
                            buttonText?.apply {
                                mDownloadBtn.setText(this, 0)
                            }?:run{
                                mDownloadBtn.setText(context.resources.getString(R.string.download), 0)
                            }
                        }
                        ApullConst.STATUS_TYPE_DOWNLOADING ->{
                            mDownloadBtn.setText(context.resources.getString(R.string.downloading), 0)
                        }
                        ApullConst.STATUS_TYPE_UPDATE_PROGRESS -> {
                            mDownloadBtn.setText("$progress%", progress)
                        }
                        ApullConst.STATUS_TYPE_DOWNLOAD_PAUSED ->{
                            mDownloadBtn.setText(context.resources.getString(R.string.resume), progress)
                        }
                        ApullConst.STATUS_TYPE_DOWNLOAD_CANCELED ->{
                            buttonText?.apply {
                                mDownloadBtn.setText(this, 0)
                            }?:run{
                                mDownloadBtn.setText(context.resources.getString(R.string.download), 0)
                            }
                        }
                        ApullConst.STATUS_TYPE_DOWNLOAD_DELETED ->{
                            buttonText?.apply {
                                mDownloadBtn.setText(this, 0)
                            }?:run{
                                mDownloadBtn.setText(context.resources.getString(R.string.download), 0)
                            }
                        }
                        ApullConst.STATUS_TYPE_DOWNLOAD_FAILED ->{
                            buttonText?.apply {
                                mDownloadBtn.setText(this, 0)
                            }?:run{
                                mDownloadBtn.setText(context.resources.getString(R.string.download), 0)
                            }
                        }
                        ApullConst.STATUS_TYPE_DOWNLOAD_FINISHED ->{
                            mDownloadBtn.setText(context.resources.getString(R.string.install), progress)
                            updateButtonStyleStateOpen()
                        }
                        ApullConst.STATUS_TYPE_INSTALL ->{
                            mDownloadBtn.setText(context.resources.getString(R.string.install),progress)
                            updateButtonStyleStateOpen()
                        }
                        ApullConst.STATUS_TYPE_INSTALLING ->{
                            mDownloadBtn.setText(context.resources.getString(R.string.installing),progress)
                            updateButtonStyleStateOpen()
                        }
                        ApullConst.STATUS_TYPE_INSTALL_FAILED ->{
                            mDownloadBtn.setText(context.resources.getString(R.string.install), progress)
                            updateButtonStyleStateOpen()
                        }
                        ApullConst.STATUS_TYPE_INSTALL_FINISHED ->{

                            mDownloadBtn.setText(context.resources.getString(R.string.apullsdk_hongbao_taste_app), progress)
                            updateButtonStyleStateOpen()
                        }
                        ApullConst.STATUS_TYPE_APK_OPENED ->{
                        }
                    }
                }
            }
        }
    }


    open fun updateButtonStyleStateOpen() {
        val drawable = BitmapUtil.createSolidDrawable(context, DensityUtil.dip2px(context, RADIUS_DP),
                0, Color.parseColor("#ffe5a8"), false, 1f)
        mDownloadBtn?.progressDrawable = drawable
        mDownloadBtn?.setTextColor(Color.parseColor("#f1321e"))
    }

    override fun onBackPressed() {
        checkBack()
    }

    override fun onClick(v: View?) {
        if(isClickTooFast){
            return
        }
       when(v?.id){
           R.id.mDownloadClose -> {
               checkBack()
           }
           R.id.mDownloadBtn -> {
               if(mRewardCome && mRewardInfo?.hasRewardOpenChance() == true && !openAppShouldCloseDialog && !mCommitTimeOut){
                   if (mContext is RaffleBaseActivity) {
                       (mContext as RaffleBaseActivity).startRewardCommit( mRewardInfo)
                       return
                   }
               }else{
                   handleNoReward()
               }
           }
           R.id.mDownloadIcon ->{
               if(mRewardType == RewardUtils.REWARD_TYPE_APP) {
                   handleNoReward()
               }
           }
       }
    }

    open fun handleNoReward(){
        tryCatch {
            if(mRewardType == RewardUtils.REWARD_TYPE_APP){
                if(!mCommitTimeOut) {
                    handleAppClick()
                }else{
                    dismiss()
                    showFailRewardDialog()
                }
                if(openAppShouldCloseDialog && mApullItemWrapper?.getDownloadStatus() == ApullConst.STATUS_TYPE_INSTALL_FINISHED){
                    dismiss()
                    showFailRewardDialog()
                }
            }else if(mRewardType == RewardUtils.REWARD_TYPE_OPEN || mRewardType == RewardUtils.REWARD_TYPE_OPEN_DEEP_LINK){
                if(openAppShouldCloseDialog || mCommitTimeOut){
                    dismiss()
                    showFailRewardDialog()
                }
            }

        }
    }

    fun handleAppClick() {
       mDownloadListener?.onClick()
    }

    fun getApullItemWrapper() : ApullItemWrapper?{
        return mApullItemWrapper
    }

    fun updateFailRewardInfo(rewardInfo: RewardUtils.RewardInfo?,status: Int,rewardType:Int){
        mRewardType = rewardType
        updateText(status)
        updateButtonStyleStateOpen()
    }

    fun updateSuccessRewardInfo(rewardInfo: RewardUtils.RewardInfo?){
        if(rewardInfo == null || rewardInfo.apullAdItem?.equalsUniqueId(mApullItemWrapper) == false){
            return
        }

        rewardInfo.apply {
            mRewardInfo = rewardInfo
            mRewardType = rewardInfo.rewardType
        }.apply {
            val time = mRewardInfo?.mPlayTime ?:0
            if (mRewardType != RewardUtils.REWARD_TYPE_APP) {
                mTasteTipsGuide.setVisible(false)
                mDownloadTips.setVisible(false)
            } else {
                if(mRewardInfo?.isHourOpenType == true){//APP协议整点红包打开类
                    mTasteTipsGuide.setVisible(false)
                    mDownloadTips.setVisible(false)
                }else {
                    if (mApullItemWrapper?.getDownloadStatus() != ApullConst.STATUS_TYPE_INSTALL_FINISHED) {
                        mTasteTipsGuide.setVisible(false)
                        mDownloadTips.setVisible(true)
                    } else {
                        mTasteTipsGuide.setVisible(true)
                        mDownloadTips.setVisible(false)
                        if (time == 0) {
                            mTasteTipsGuide.text = context.getString(R.string.apullsdk_hongbao_taste_tips_one)
                        } else if (time < RewardUtils.TASTE_APP_TIME && time > 0) {
                            mTasteTipsGuide.text = context.getString(R.string.apullsdk_hongbao_taste_tips_two, RewardUtils.TASTE_APP_TIME - time)
                            val mAnimationShake = AnimationShake(mTasteTipsGuide)
                            mAnimationShake.startAnimate()
                        } else if (time >= RewardUtils.TASTE_APP_TIME) {
                            mTasteTipsGuide.text = ""
                        }
                    }
                }
            }  
        }.apply {
            when{
                hasRewardOpenChance() -> {
                    updateText(HAS_REWARD)
                }
            }
        }
        updateTextAndButton()
    }

    private fun updateText(status:Int) {
        when(status){
            INIT -> {
                mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_normal)
            }
            TIMEOUT -> {
                mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_timeout)
                mDownloadTips.setVisible(true)
                mTasteTipsGuide.setVisible(false)
                mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open_reward), mApullItemWrapper?.getDownloadProgress() ?: 0)
                mCommitTimeOut = true
            }
            DONT_HAS_CHANCE ->{
                openAppShouldCloseDialog = true
                mDownloadText.text = ""
                mDownloadTips.setVisible(true)
                mTasteTipsGuide.setVisible(false)
                mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open), mApullItemWrapper?.getDownloadProgress() ?: 0)
            }
            SHARE_MORE_CHANCE -> {
                openAppShouldCloseDialog = true
                mShareCanTryAgain = true
                mDownloadText.text = ""
                mDownloadTips.setVisible(true)
                mTasteTipsGuide.setVisible(false)
                mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open), mApullItemWrapper?.getDownloadProgress() ?: 0)
            }
            HAS_REWARD ->{
                mRewardCome = true
                mDownloadText.setVisible(true)
                mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_has_hongbao)
                mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open_reward), mApullItemWrapper?.getDownloadProgress() ?: 0)
            }
        }

        //APP协议整点红包打开类
        if(mRewardInfo?.isHourOpenType == true || mApullItemWrapper?.isHourOpenType() == true){
            mDownloadTips.setVisible(false)
            mTasteTipsGuide.setVisible(false)
            if(!(mRewardCome || mCommitTimeOut)) {
                mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open_h5), mApullItemWrapper?.getDownloadProgress()
                        ?: 0)
            }
        }
        //激活或注册类红包
        if(mRewardInfo?.isActivateOrRegisterType == true || mApullItemWrapper?.isActivateOrRegisterType() == true){
            if(mRewardInfo == null){
                mDownloadTips?.setVisible(true)
                mTasteTipsGuide?.setVisible(false)
                mDownloadTips?.text = context.resources.getString(R.string.apullsdk_hongbao_activate_register)
            }else {
                val time = mRewardInfo!!.mPlayTime
                if(mRewardInfo!!.rewardType == RewardUtils.REWARD_TYPE_APP) {
                    if (time == 0) {
                        mDownloadTips?.setVisible(false)
                        mTasteTipsGuide?.setVisible(true)
                        mTasteTipsGuide.text = context.getString(R.string.apullsdk_hongbao_taste_tips_one)
                    } else if (time < RewardUtils.TASTE_APP_TIME && time > 0) {
                        mDownloadTips?.setVisible(false)
                        mTasteTipsGuide?.setVisible(true)
                        mTasteTipsGuide.text = context.getString(R.string.apullsdk_hongbao_taste_tips_two, RewardUtils.TASTE_APP_TIME - time)
                    } else if (time >= RewardUtils.TASTE_APP_TIME) {
                        mDownloadTips?.setVisible(true)
                        mTasteTipsGuide?.setVisible(false)
                        mDownloadTips?.text = context.resources.getString(R.string.apullsdk_hongbao_activate_register)
                    }
                }
            }
        }
    }

    fun showFailRewardDialog() {
          tryCatch{
              if(mContext is RaffleBaseActivity) {
                  (mContext as RaffleBaseActivity).showRewardResultDialog(mRewardInfo,false,mShareCanTryAgain)
              }
          }
    }

   private fun updateTextAndButton() {
        if (mRewardInfo != null) {
            val mPlayTime = mRewardInfo!!.mPlayTime
            if (mRewardType == RewardUtils.REWARD_TYPE_APP) {
                if(mRewardInfo?.isHourOpenType == true) {
                    if (mRewardCome) {
                        mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open_reward), mApullItemWrapper?.getDownloadProgress()
                                ?: 0)
                        mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_has_hongbao)
                    } else {
                        mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_normal)
                        mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open_h5), mApullItemWrapper?.getDownloadProgress()
                                ?: 0)
                    }
                }else {
                    if (mPlayTime < RewardUtils.TASTE_APP_TIME) {
                        mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_normal)
                        mDownloadBtn.setText(context.resources.getString(R.string.apullsdk_hongbao_taste_app), mApullItemWrapper?.getDownloadProgress()
                                ?: 0)
                    } else {
                        if (mRewardCome) {
                            mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open_reward), mApullItemWrapper?.getDownloadProgress()
                                    ?: 0)
                            mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_has_hongbao)
                        } else {
                            mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_normal)
                            mDownloadBtn.setText(context.resources.getString(R.string.apullsdk_hongbao_taste_app), mApullItemWrapper?.getDownloadProgress()
                                    ?: 0)
                        }
                    }
                }
            } else {
                if (mRewardCome) {
                    mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_has_hongbao)
                    mDownloadBtn.setText(context.resources.getString(R.string.hongbao_open_reward), mApullItemWrapper?.getDownloadProgress() ?: 0)

                } else {
                    mDownloadText.text = context.resources.getString(R.string.hongbao_download_text_normal)
                    mDownloadBtn.setText(context.resources.getString(R.string.apullsdk_hongbao_taste_app), mApullItemWrapper?.getDownloadProgress() ?: 0)
                }
            }
            updateButtonStyleStateOpen()
        }
    }

    private fun checkBack() {
        // 抢到红包时与下载应用时使用不同文案，如果没抢到红包，直接关闭dialog
        var content: Int
        var ok: String
        var cancle: String

        if (mApullItemWrapper?.getDownloadStatus() == ApullConst.STATUS_TYPE_INSTALL_FINISHED) {
            if (mRewardInfo != null) {
                content = R.string.hongbao_chance_dialog_content
                if (mRewardInfo?.rewardType == RewardUtils.REWARD_TYPE_APP && mRewardInfo?.mPlayTime ?:0 < RewardUtils.TASTE_APP_TIME) {
                    content = R.string.hongbao_chance_dialog_content_taste
                }
                ok = context.resources.getString(R.string.hongbao_chance_dialog_ok)
                cancle = context.resources.getString(R.string.hongbao_chance_dialog_cancel)
            } else {
                dismiss()
                return
            }
        } else {

            val chance = mRewardInfo?.tryResponse?.chances ?: 0
            val share = mRewardInfo?.tryResponse?.share ?: 0
            content = if (chance <= 0 && share <= 0) {
                R.string.hongbao_download_dialog_nochance_content
            } else {
                R.string.hongbao_download_dialog_content
            }

            if(mRewardInfo?.rewardType == RewardUtils.REWARD_TYPE_OPEN){
                content =  R.string.hongbao_chance_dialog_content
            }
            //整点红包提示
            if (mRewardInfo?.isHourOpenType == true || mApullItemWrapper?.isHourOpenType() == true ) {
                content = R.string.hongbao_download_dialog_content;
            }
            ok = context.resources.getString(R.string.hongbao_download_dialog_ok)
            cancle = context.resources.getString(R.string.hongbao_download_dialog_cancel)
        }

        val exitDialog = CommonDialog(context, R.string.hongbao_chance_dialog_title, content)
        exitDialog.setBtnOk(cancle, View.OnClickListener {
            if (isClickTooFast) {
                return@OnClickListener
            }

            mDownloadListener?.onContinue()

            tryCatch {
                exitDialog.dismiss()
            }
        })
        exitDialog.setBtnCancel(ok, View.OnClickListener {
            if (isClickTooFast) {
                return@OnClickListener
            }

            mDownloadListener?.onDismiss()

            if(mContext is RaffleBaseActivity){
                (mContext as RaffleBaseActivity).onBackPressedDownDialog(mRewardInfo)
            }

            tryCatch {
                exitDialog.dismiss()
                dismiss()
            }
        })
        exitDialog.show()
    }

    override fun onDownload(downloadid: String?) {
        Logger.d(TAG,"ThreadName: "+ Thread.currentThread().name)
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_DOWNLOAD)
                updateStatus(this)
                Logger.d(TAG, "onDownload downloadid:$downloadid")
            }
        }
    }

    override fun onProgressUpdate(downloadid: String?, progress: Int, filePath: String?) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_UPDATE_PROGRESS)
                setDownloadFilePath(filePath)
                setDownloadProgress(progress)
                updateStatus(this)
                Logger.d(TAG, "onProgressUpdate downloadid:$downloadid")
            }
        }
    }

    override fun onDownloadFinished(downloadid: String?, filePath: String?) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_DOWNLOAD_FINISHED)
                updateStatus(this)
                Logger.d(TAG, "onDownloadFinished downloadid:$downloadid")
            }
        }
    }

    override fun onDownloadFailed(downloadid: String?, errorCode: Int) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_DOWNLOAD_FAILED)
                updateStatus(this)
                Logger.d(TAG, "onDownloadFailed downloadid:$downloadid")
            }
        }
    }

    override fun onDownloadPaused(downloadid: String?) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_DOWNLOAD_PAUSED)
                updateStatus(this)
                Logger.d(TAG, "onDownloadPaused downloadid:$downloadid")
            }
        }
    }

    override fun onDownloadResumed(downloadid: String?) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_DOWNLOAD)
                updateStatus(this)
                Logger.d(TAG, "onDownloadResumed downloadid:$downloadid")
            }
        }
    }

    override fun onDownloadCanceled(downloadid: String?) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_DOWNLOAD_CANCELED)
                updateStatus(this)
                Logger.d(TAG, "onDownloadCanceled downloadid:$downloadid")
            }
        }
    }

    override fun onStartInstallApk(downloadid: String?) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_INSTALL)
                updateStatus(mApullItemWrapper)
                Logger.d(TAG, "onStartInstallApk downloadid:$downloadid")
            }
        }

    }

    override fun onInstallingApk(downloadid: String?) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_INSTALLING)
                updateStatus(this)
                Logger.d(TAG, "onInstallingApk downloadid:$downloadid")
            }
        }
    }

    override fun onApkInstalled(downloadid: String?, iType: Int) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadiType(iType)
                setDownloadStatus(ApullConst.STATUS_TYPE_INSTALL_FINISHED)
                updateStatus(this)
                Logger.d(TAG, "onApkInstalled downloadid:$downloadid")
            }
        }
    }

    override fun onApkInstallFailed(downloadid: String?) {
        mApullItemWrapper?.apply {
            if (equalsDownloadId(downloadid)) {
                setDownloadStatus(ApullConst.STATUS_TYPE_INSTALL_FAILED)
                updateStatus(mApullItemWrapper)
            }
        }
    }

    interface DownloadListener {

        fun onClick()

        fun onDismiss()

        fun onContinue()
    }

    fun setDownloadListener(listener: DownloadListener){
        this.mDownloadListener = listener
    }
}
